# :toilet: Bidet


<p align="center">
    <a href="https://github.com/poopingface/bidet/blob/main/LICENSE">
        <img alt="GitHub" src="https://img.shields.io/github/license/poopingface/bidet.svg?color=blue">
    </a>
    <a href="https://poopingface.github.io">
        <img alt="Website" src="https://img.shields.io/website/http/poopingface.github.io/index.html?down_color=red&down_message=offline&up_message=online">
    </a>
    <a href="https://github.com/poopingface/bidet/releases">
        <img alt="GitHub release" src="https://img.shields.io/github/release/poopingface/bidet.svg">
    </a>
</p>

*Coming soon, the **cleanest** machine learning library.*

## Installation

```bash
pip install bidet
```

